from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .all_environment_secrets_response_secrets import AllEnvironmentSecretsResponse_secrets

@dataclass
class AllEnvironmentSecretsResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The environmentName property
    environment_name: Optional[str] = None
    # The environmentSlug property
    environment_slug: Optional[str] = None
    # The lastModified property
    last_modified: Optional[datetime.datetime] = None
    # The secrets property
    secrets: Optional[AllEnvironmentSecretsResponse_secrets] = None
    # The version property
    version: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> AllEnvironmentSecretsResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: AllEnvironmentSecretsResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return AllEnvironmentSecretsResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .all_environment_secrets_response_secrets import AllEnvironmentSecretsResponse_secrets

        from .all_environment_secrets_response_secrets import AllEnvironmentSecretsResponse_secrets

        fields: dict[str, Callable[[Any], None]] = {
            "environmentName": lambda n : setattr(self, 'environment_name', n.get_str_value()),
            "environmentSlug": lambda n : setattr(self, 'environment_slug', n.get_str_value()),
            "lastModified": lambda n : setattr(self, 'last_modified', n.get_datetime_value()),
            "secrets": lambda n : setattr(self, 'secrets', n.get_object_value(AllEnvironmentSecretsResponse_secrets)),
            "version": lambda n : setattr(self, 'version', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("environmentName", self.environment_name)
        writer.write_str_value("environmentSlug", self.environment_slug)
        writer.write_datetime_value("lastModified", self.last_modified)
        writer.write_object_value("secrets", self.secrets)
        writer.write_int_value("version", self.version)
        writer.write_additional_data_value(self.additional_data)
    

